@@ -1,18 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  lets the user choose a nick from the list
-  begin:     Sam Dez 7 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
-*/
-/*
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #ifndef RECIPIENTDIALOG_H
@@ -38,7 +28,7 @@ namespace Konversation
 
                 static QString getNickname(QWidget* parent, QAbstractListModel* model);
 
-            protected Q_SLOTS:
+            private Q_SLOTS:
                 void newNicknameSelected(const QModelIndex& index);
                                                           // KDE double click
                 void newNicknameSelectedQuit(const QModelIndex& index);
@@ -46,11 +36,15 @@ namespace Konversation
                 void slotOk();
                 void slotCancel();
 
-            protected:
-                QString getSelectedNickname();
+            private:
+                QString getSelectedNickname() const;
+
+            private:
                 static QString selectedNickname;
 
                 KLineEdit* nicknameInput;
+
+                Q_DISABLE_COPY(RecipientDialog)
         };
     }
 }
