@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #ifndef WHITEBOARDTOOLBAR_H
@@ -75,7 +70,7 @@ namespace Konversation
                 void save(const QString& filename);
                 void clear();
 
-            protected Q_SLOTS:
+            private Q_SLOTS:
                 void clearClicked();
                 void saveClicked();
 
@@ -113,6 +108,7 @@ namespace Konversation
 
                 inline void fillFormOptionList(FormOption form);
 
+            private:
                 QHash<Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool, QPushButton*> m_toggleButtonHash;
                 QPixmap m_lineWidthPixmap;
 
@@ -124,6 +120,8 @@ namespace Konversation
 
                 Konversation::DCC::WhiteBoardToolBar::TextType m_textType;
                 WhiteBoardFontChooser* m_fontDialog;
+
+                Q_DISABLE_COPY(WhiteBoardToolBar)
         };
     }
 }
