@@ -1,23 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
-*/
-
-/*
-  Copyright (C) 2010 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2010 Eike Hein <hein@kde.org>
 */
 
 #ifndef URLCATCHER_H
@@ -30,7 +14,7 @@
 
 
 class QTreeView;
-
+class QLineEdit;
 class QMenu;
 class KToolBar;
 
@@ -42,6 +26,9 @@ class UrlDateItem : public QStandardItem
         ~UrlDateItem() override;
 
         QVariant data(int role) const override;
+
+  private:
+        Q_DISABLE_COPY(UrlDateItem)
 };
 
 
@@ -50,14 +37,16 @@ class UrlSortFilterProxyModel : public QSortFilterProxyModel
     Q_OBJECT
 
     public:
-        explicit UrlSortFilterProxyModel(QObject* parent = 0);
+        explicit UrlSortFilterProxyModel(QObject* parent = nullptr);
         ~UrlSortFilterProxyModel() override;
 
         Qt::ItemFlags flags(const QModelIndex& index) const override;
 
-
     protected:
         bool lessThan(const QModelIndex& left, const QModelIndex& right) const override;
+
+    private:
+        Q_DISABLE_COPY(UrlSortFilterProxyModel)
 };
 
 
@@ -88,11 +77,14 @@ class UrlCatcher : public ChatWindow
         void saveUrlModel();
         void clearUrlModel();
 
+        void updateFilter();
+        void startFilterTimer(const QString &filter);
 
     private:
         void setupActions();
         void setupUrlTree();
 
+    private:
         KToolBar* m_toolBar;
         QMenu* m_contextMenu;
 
@@ -100,6 +92,10 @@ class UrlCatcher : public ChatWindow
         QList<QAction*> m_listActions;
 
         QTreeView* m_urlTree;
+        QLineEdit* m_searchLine;
+        QTimer* m_filterTimer;
+
+        Q_DISABLE_COPY(UrlCatcher)
 };
 
 #endif
