@@ -133,7 +133,7 @@ namespace Konversation
             if (!m_ui.topicEdit->isReadOnly())
                 m_ui.topicEdit->setFocus();
 
-            KConfigGroup config(KSharedConfig::openConfig(), "ChannelOptionsDialog");
+            KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("ChannelOptionsDialog"));
 
             resize(config.readEntry("Size", sizeHint()));
 
@@ -150,7 +150,7 @@ namespace Konversation
 
     void ChannelOptionsDialog::hideEvent(QHideEvent* event)
     {
-        KConfigGroup config(KSharedConfig::openConfig(), "ChannelOptionsDialog");
+        KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("ChannelOptionsDialog"));
 
         config.writeEntry("Size", size());
         config.writeEntry("SplitterSizes", m_ui.splitter->sizes());
@@ -275,7 +275,7 @@ namespace Konversation
                 QList<QStandardItem*> items = model->findItems(QStringLiteral("*"), Qt::MatchWildcard, 0);
                 items += model->findItems(QStringLiteral("*"), Qt::MatchWildcard, 1);
 
-                for (QStandardItem* item : qAsConst(items))
+                for (QStandardItem* item : std::as_const(items))
                     item->setEnabled(m_isAnyTypeOfOp);
             }
 
@@ -312,7 +312,7 @@ namespace Konversation
         modesModel->clear();
         modesModel->setHorizontalHeaderLabels(QStringList { i18n("Mode"), i18n("Parameter") });
 
-        for (const QChar mode : qAsConst(modeString)) {
+        for (const QChar mode : std::as_const(modeString)) {
             const QString modeAsString(mode);
 
             QStandardItem *item = nullptr;
@@ -366,11 +366,7 @@ namespace Konversation
                     break;
                 case 'l':
                     m_ui.userLimitChBox->setChecked(true);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                    m_ui.userLimitEdit->setValue(currentMode.midRef(1).toInt());
-#else
                     m_ui.userLimitEdit->setValue(QStringView(currentMode).mid(1).toInt());
-#endif
                     break;
                 case 'i':
                     m_ui.inviteModeChBox->setChecked(true);
@@ -596,7 +592,7 @@ namespace Konversation
         if (treeWidget()->sortColumn() == 2)
         {
             QVariant userdata = item.data(2, Qt::UserRole);
-            if (userdata.isValid() && userdata.type() == QVariant::DateTime)
+            if (userdata.isValid() && userdata.typeId() == QVariant::DateTime)
             {
               return m_timestamp < userdata.toDateTime();
             }
