@@ -1,14 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  begin:     Mon Jun 24 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #ifndef IGNORE_H
@@ -34,14 +27,17 @@ class Ignore
         };
 
         Ignore(const QString &name,int flags);
+        Ignore(const Ignore& other) = default;
         ~Ignore();
 
+        Ignore& operator=(const Ignore& other) = default;
+
         void setName(const QString &newName);
         void setFlags(int newFlags);
         QString getName() const;
         int getFlags() const;
 
-    protected:
+    private:
         QString name;
         int flags;
 };
